<?php

namespace App\Http\Controllers\API\v1;


use App\Models\Age;
use App\Models\Area;
use App\Models\Cart;
use App\Models\Page;
use App\Models\Size;
use App\Models\Color;
use App\Models\Token;
use App\Models\Banner;
use App\Models\Contact;
use App\Models\Product;
use App\Models\Service;

use App\Models\Setting;
use App\Models\Category;

use App\Models\Location;
use App\Models\Governorate;
use Illuminate\Http\Request;
use App\Models\Advertisement;
use Illuminate\Support\Collection;

use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;


class AppController extends Controller
{
    public function __construct()
    {
        $this->paginate = 15;

    }

 

    public function getGovernorates()
    {
        $items = Governorate::where('status', 'active')->get();
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message, 'items' => $items]);
    }
    
    public function getAreas(Request $request)
    {
        $items = Area::where('status', 'active');
        if($request->governorate_id !=''){
            $items->where('governorate_id',$request->governorate_id);
        }
        $items = $items->get();
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message, 'items' => $items]);
    }
    public function getCategories()
    {
        $items = Category::where('status', 'active')->get();
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message, 'items' => $items]);
    }


    public function getLocations(Request $request)
    {

       $items = Location::where('status','active')->with('governorate','area')->paginate(15)->items();

       $is_more = (15 > count($items))? false:true;
    
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message, 'items' => $items,'is_more'=>$is_more]);
    }
    

    public function getBanners()
    {
        $banners = Banner::query()->where('status', 'active')->get();
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message, 'items' => $banners]);
    }
    
    public function getCategoryDetails($id)
    {
        $category = Category::query()->where('id', $id)->with(['subCategories'])->first();
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message, 'item' => $category]); 
    }
    


 

    public function getSetting()
    {

        $settings = Setting::query()->first();
        $settings['pages'] = Page::get();
        $settings['colors']=Color::get();
        $settings['sizes']=Size::get();
        $settings['ages']=Age::get();
        $settings['categories']= Category::where('status', 'active')->get();
        $settings['advertisements']= Advertisement::where('status', 'active')->get();
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message, 'settings' => $settings]);

    }

    public function updateMyLanguage(Request $request)
    {

        $check=Token::where('fcm_token' , $request->get('fcmToken'))->first();
        if($check){
            $check->lang=$request->get('lang');
            $check->save();
        }else{
             Token::updateOrCreate(['fcm_token' => $request->get('fcmToken'), 'device_type' => $request->get('device_type'),
            'lang' => $request->get('lang')]);
        }

         \App::setLocale($request->get('lang'));

        $settings = Setting::query()->first();
        $settings['pages'] = Page::get();
        $settings['colors']=Color::get();
        $settings['sizes']=Size::get();
        $settings['ages']=Age::get();
        $settings['categories']= Category::where('status', 'active')->get();
        $settings['advertisements']= Advertisement::where('status', 'active')->get();

        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message, 'settings' => $settings]);
    }


    public function storeFcmToken(Request $request)
    {
   
        $token=Token::where('fcm_token' , $request->fcmToken)->
            where('device_type' , $request->device_type)->where('lang',$request->lang)->first();
            if(!$token){
                $token= new Token();
                $token->fcm_token =$request->fcmToken;
                $token->device_type =$request->device_type;
                $token->lang =$request->lang;
                $token->save();
            }
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message]);
    }

    public function pages($id)
    {
        $page = Page::where('id', $id)->first();
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message, 'page' => $page]);
    }

    public function contactUs(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'email' => 'required|email',
            'mobile' => 'required|digits_between:8,13',
            'name' => 'required',
            // 'message' => 'required',
        ]);
        if ($validator->fails()) {
         return response()->json(['status' => false, 'code' => 200,
             'message' =>implode("\n",$validator-> messages()-> all()) ]);
        }

        $contact = new  Contact();
        $contact->email = $request->get('email');
        $contact->name = $request->get('name');
        $contact->mobile = $request->get('mobile');
        $contact->message = $request->get('message');
        $contact->read = 0;
        $contact->save();

        $message = __('api.ok');

        return response()->json(['status' => true, 'code' => 200, 'message' => $message]);

    }

 
  
}
