<?php
namespace App\Http\Controllers\API\v1;

use App\Models\SearchingWord;
use App\Models\Setting;
use App\Models\Service;
use App\Models\Order;
use App\Models\Review;
use App\Models\Note;
use App\Models\Section;
use App\Models\Subadmin;
use App\Models\Favorite;
use App\Models\User;
use App\Models\Banner;
use App\Models\Category;
use App\Models\UserWallet;
use App\Models\Cart;
use App\Models\SubadminCategory;
use App\Models\Chat;
use App\Models\ChatMessages;


use App\Http\Controllers\Controller;

use App\Models\Product;
use App\Models\UserAddress;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Carbon\Carbon;

class ProductController extends Controller
{
    protected $paginateTotal = '';
    protected $settings = 'Setting';
    public function __construct()
    {
        $this->settings = Setting::orderBy('id', 'desc')->first();
        $this->paginateTotal = $this->settings->paginateTotal;
    }
 
    public function getHomePage(Request $request)
    {
        $item['banners'] = Banner::query()->where('status', 'active')->orderBy('id','desc')->take(8)->get();
        $item['main_categories'] = Category::where('status','active')->where('type',1)->orderBy('id','asc')->get();
        $item['categories'] = Category::where('status','active')->where('is_featured',1)->where('type',2)->orderBy('id','desc')->take(8)->get();
        $item['featured_products']= Product::query()->where('status', 'active')->where('is_featured',1)->orderBy('id','desc')->take(8)->get();
        $item['best_seller_products']= Product::query()->where('status', 'active')->where('is_best_seller',1)->orderBy('id','desc')->take(8)->get();
        $item['new_arrival_products']= Product::query()->where('status', 'active')->where('is_new_arrival',1)->orderBy('id','desc')->take(8)->get();
        
 
        $myCart = Cart::where(function ($q) use ($request) {
            $q->where('user_id', auth('api')->id())->orWhere('fcm_token', $request->header('fcmToken'));
        })->count();

        $item['count_products']=$myCart;

        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message,'item' => $item ]);
    }

    public function getCategoriesByType(Request $request)
    {
        $items = Category::where('status', 'active')->where('type',$request->type)->orderBy('id','desc')->get();
      
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message,'items' => $items]);
    }

 
  

    public function getProducts(Request $request)
    {
        $setting = Setting::query()->findOrFail(1);
        $products = Product::where('status', 'active');


        if ($request->has('category_id')  && $request->get('category_id') != null) {
            $products =  $products->whereHas('categories',function ($q) use($request) {
                $q->where('category_id',$request->category_id);
              });     
        }
        
        if ($request->has('categories')  && $request->get('categories') != null) {
            $products =  $products->whereHas('categories',function ($q) use($request) {
                $q->whereIn('category_id',$request->categories);
              });        
        }
        if ($request->has('is_new_arrival')  && $request->get('is_new_arrival') != null) {
            $products->where('is_new_arrival',$request->is_new_arrival);       
        }
        if ($request->has('is_best_seller')  && $request->get('is_best_seller') != null) {
            $products->where('is_best_seller',$request->is_best_seller);       
        }
        if ($request->has('is_featured')  && $request->get('is_featured') != null) {
            $products->where('is_featured',$request->is_featured);       
        }
 
        
        if ($request->has('text') && $request->get('text') != '' ) {
            $text=$request->get('text');
              $products =  $products->where(function($q) use($text){
                $q->whereTranslationLike('name', '%'. $text.'%')->orWhereTranslationLike('description', '%'. $text.'%');
              });  
              if(auth('api')->check()){
                $word=SearchingWord::where('user_id',auth('api')->id())->where('text',$request->get('text'))->first();
                if(!$word) {
                   $word= new SearchingWord();
                   $word->user_id=auth('api')->id();
                   $word->text=$request->get('text');
                   $word->save();
                }
              }

        }

        if ($request->has('colors')  && $request->get('colors') != null) {
            $products =  $products->whereHas('colors',function ($q) use($request) {
                $q->whereIn('color_id',$request->colors);
              });      
        }
        if ($request->has('sizes')  && $request->get('sizes') != null) {
            $products =  $products->whereHas('sizes',function ($q) use($request) {
                $q->whereIn('size_id',$request->sizes);
              });      
        }
        if ($request->has('age_id')  && $request->get('age_id') != null) {
            $products =  $products->whereHas('ages',function ($q) use($request) {
                $q->where('age_id',$request->age_id);
              });      
        }
        if ($request->has('ages')  && $request->get('ages') != null) {
            $products =  $products->whereHas('ages',function ($q) use($request) {
                $q->whereIn('age_id',$request->ages);
              });      
        }

        if ($request->get('price_from') && $request->get('price_to') != '' ) {
            $products =  $products->whereBetween('price', [$request->price_from, $request->price_to]);;      
        }

        if ($request->has('has_offer')  && $request->get('has_offer') ==1) {
            $products =  $products->where('discount_price','>',0)->whereDate('offer_end_date','>', now()->toDateString());     
          }
    

      
         
        if ($request->has('sorting_type') && $request->get('sorting_type') !='') {
            if($request->sorting_type=='new_arrival'){
                $products =  $products->orderBy('is_new_arrival','desc');
         
            }if($request->sorting_type=='best_seller'){
                $products =  $products->orderBy('is_best_seller','desc');
         
            }elseif($request->sorting_type=='price_asc'){
                $products =  $products->orderBy('price','asc');
         
            }elseif($request->sorting_type=='price_desc'){
                $products =  $products->orderBy('price','desc');
           
            }elseif($request->sorting_type=='alpha_asc'){
                $products->orderByRaw("(SELECT name FROM product_translations WHERE product_id = products.id and  locale = '" . app()->getLocale() . "') ASC");

            }elseif($request->sorting_type=='alpha_desc'){
                $products->orderByRaw("(SELECT name FROM product_translations WHERE product_id = products.id and  locale = '" . app()->getLocale() . "') DESC");
         
            }
            $products =  $products->paginate($this->paginateTotal); 

        }else{
            $products =  $products->orderBy('id','desc')->paginate($this->paginateTotal);  
        }
 
        $count_products =$products->total() ;
        $products =$products->items();

        $is_more = ($this->paginateTotal > count($products)) ? false : true;
 

        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message,
        'count_products'=>$count_products,'items' => $products ,'is_more'=>$is_more ]);
    }
    public function searchProducts(Request $request)
    {
        $products = Product::where('status', 'active');

        if ($request->has('text') && $request->get('text') != '' ) {
            $text=$request->get('text');
              $products =  $products->where(function($q) use($text){
                $q->whereTranslationLike('name', '%'. $text.'%')->orWhereTranslationLike('description', '%'. $text.'%');
              });
              if(auth('api')->check()){
                $word=SearchingWord::where('user_id',auth('api')->id())->where('text',$request->get('text'))->first();
                if(!$word) {
                   $word= new SearchingWord();
                   $word->user_id=auth('api')->id();
                   $word->text=$request->get('text');
                   $word->save();
                }
              }

        }

         
        $products =  $products->orderBy('id','desc')->paginate($this->paginateTotal);  
 
        $count_products =$products->total() ;
        $products =$products->items();

        $is_more = ($this->paginateTotal > count($products)) ? false : true;

        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message,
        'count_products'=>$count_products,'items' => $products ,'is_more'=>$is_more ]);
    }



    public function getProductDetails(Request $request,$id)
    {
        $product = Product::where('status', 'active')->with('categories.category','colors.color','sizes.size','ages.age','images')->findOrFail($id);
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message,'items' => $product]);

    }

    public function getMyFavorites(Request $request)
    {

       $user_id =auth('api')->id();
       
       $items = Product::whereHas('favorites',function($q){
        $q->where('user_id', auth('api')->id());
       })->orderByRaw("(SELECT id FROM favorites  WHERE item_id = products.id and  user_id = '$user_id') desc")
        ->paginate($this->paginateTotal)->items();

       $is_more = ($this->paginateTotal > count($items))? false:true;
    
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message, 'items' => $items,'is_more'=>$is_more]);
    }
    
    
        public function addAndRemoveFromFavorite(Request $request,$item_id){

        $item = Product::where('status', 'active')->findOrFail($item_id);
        $favorite= Favorite::where('user_id',auth('api')->id())->where('item_id',$item_id)->first();
        if($favorite){
            $favorite->delete();

        }else{
            $new_fav = new Favorite();
            $new_fav->user_id=auth('api')->id();
            $new_fav->item_id=$item_id;
            $new_fav->save();
        }
           return response()->json(['status' => true, 'code' => 200, 'message' => __('api.ok')]);
        
    }

    public function getSearchingWords(Request $request)
    {

        $user_id =auth('api')->id();
       
        $items = SearchingWord::where('user_id',$user_id)->orderBy('id','desc')->take(20)->get();

        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message, 'items' => $items]);
    }
 

}







