<?php

namespace App\Http\Controllers\API\v1;
use App\Admin;
use App\Models\UserService;

use App\Notifications\ResetPassword;
use Carbon\Carbon;
use Illuminate\Support\Facades\Password;
use App\Models\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use App\Models\Token;
use App\Models\Setting;
use App\Models\Language;
use App\Models\Favorite;
use App\Models\Order;
use App\Models\Notify;
use App\Models\Cart;
use App\Models\UserWallet;
use Illuminate\Support\Facades\Mail;
use App\Models\UserAddress;
use App\Models\Notifiy;
use Illuminate\Support\Facades\Validator;
use Illuminate\Foundation\Auth\SendsPasswordResetEmails;
use Image;
use DB;
use Laravel\Socialite\Facades\Socialite;
use Illuminate\Support\Str;
class UserController extends Controller
{
    use SendsPasswordResetEmails;

    protected $paginateTotal = '10';
    protected $settings = '';
    public function __construct(){
        $this->settings = Setting::orderBy('id', 'desc')->first();
        $this->paginateTotal = $this->settings->paginateTotal;
    }

    
    public function broker()
    {
        return Password::broker('users');
    }

    public function signUp(Request $request)
    {
        $setting=Setting::query()->first();
        if ($setting->is_alowed_register == 0) {
            $message = __('api.registerStoped');
            return response()->json(['status' => true, 'message' => $message]);
        }

        $validator = Validator::make($request->all(), [
           'name' => 'required',
           'mobile' => 'digits_between:8,15|unique:users',
           'email' => 'required|email|unique:users',
           'password' => 'required|min:6',
        ]);
     
        if ($validator->fails()) {
            return response()->json(['status' => false, 'code' => 200,
                'message' =>implode("\n",$validator-> messages()-> all()) ]);
        }
 
        $newUser = new User();
        $newUser->name = $request->get('name');;
        $newUser->email = $request->get('email');
        $newUser->mobile = convertAr2En($request->get('mobile')) ;
        $newUser->password = bcrypt($request->get('password'));
        $newUser->save();

        if ($newUser) {
            if ($request->has('fcm_token')) {
                Token::updateOrCreate(['device_type' => $request->get('device_type'),'fcm_token' => $request->get('fcm_token'),'lang'=>app()->getLocale()],['user_id' => $newUser->id]);
            }
 
        $user=User::findOrFail($newUser->id);
        Auth::login($user);
        $user['access_token'] = $user->createToken('mobile')->accessToken;
           
        
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message,'user'=>$user]);
        }
        $massege =__('api.whoops');
        return response()->json(['status' => false, 'code' => 200, 'message' => $massege ]);
    }

    public function login(Request $request)
    {
         $settings = Setting::first();
        if ($settings->is_alowed_login == 0) {

            $message = __('api.loginStoped');
            return response()->json(['status' => true, 'code'=>202,  'message' => $message]);
        } 
        
        $mobile = $request->get('mobile');
        $password = $request->get('password');

        $validator = Validator::make($request->all(), [
            'email' => 'required',
            'password' => 'required',
        ]);
        if ($validator->fails()) {
            return response()->json(['status' => false, 'code' => 200,
                'message' => implode("\n",$validator-> messages()-> all()) ]);
        }

        if (filter_var($request->email, FILTER_VALIDATE_EMAIL)) {
            $conditions = ['email' => $request->email, 'password' => $request->password];
        }
        else {
            $conditions = ['mobile' => $request->email, 'password' => $request->password];
        }
        
        if (Auth::once($conditions)) {

            $user = Auth::user();

            if ($user->status == 'not_active') {
                $message = (app()->getLocale() == "ar") ? 'الحساب غير مفعل' : 'The account is not active';
                return response()->json(['status' => false, 'code' => 210, 'message' =>
                    $message ]);
            }else {
                if ($request->has('fcm_token')) {
                    Token::updateOrCreate(['device_type' => $request->get('device_type'),'fcm_token' => $request->get('fcm_token')],['user_id' => $user->id]);
                }
                $user=User::findOrFail($user->id);
                $user['access_token'] = $user->createToken('mobile')->accessToken;


                return response()->json(['status' => true, 'code' => 200 ,'user' => $user]);
            }
        } else {
                $message = __('api.wrongLoginEmail');
                return response()->json(['status' => false, 'code' => 200 , 'message'=>$message ]);

        }
    }



    public function forgotPassword(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'email'=>'required|email',
        ]);
        //  return redirect()->back()->with('error','The email is required');
        if ($validator->fails()) {
            return response()->json(['status' => false, 'code' => 200,
                'message' =>implode("\n",$validator-> messages()-> all()) ]);
        }
        $user = User::where('email', $request->email)->first();

        if (!$user) {
            $message = 'The email not found';
            return response()->json(['status' => false, 'code' => 200,'message' => $message ]);
        }
        DB::table('password_resets')->insert([
            'email' => $user->email,
            'token' => str_random(60),
            'created_at' => Carbon::now()
        ]);
        $tokenData = DB::table('password_resets')
    ->where('email', $user->email)->first();

        $user->notify(new ResetPassword($tokenData->token,$user));

 
        $message=__('api.resetPassword');
        return response()->json(['status' => true, 'code' => 200,'message' => $message ]);
    }

    public function editUserProfile(Request $request)
    {
        $user_id = auth('api')->id();
        $user = User::query()->findOrFail($user_id);
        $validator = Validator::make($request->all(),[
            'name' => 'required',
            'mobile' => 'required|unique:users,mobile,'.$user->id,
            'email' => 'required|email:filter|unique:users,email,'.$user->id,
            ]);

        if ($validator->fails()) {
            return response()->json(['status' => false, 'code' => 200,
                'message' =>implode("\n",$validator-> messages()-> all()) ]);
        }
        $name = ($request->has('name')) ? $request->get('name') : $user->name;
        $email = ($request->has('email')) ? $request->get('email') : $user->email;
        $mobile = (convertAr2En($request->get('mobile'))) ? $request->get('mobile') : $user->mobile;

        $user->name = $name;
        $user->email = $email;
        $user->mobile = $mobile;
        
        $user->save();
 
        if ($user) {
    
            if ($request->has('fcm_token')) {
                Token::updateOrCreate(['device_type' => $request->get('device_type'),'fcm_token' => $request->get('fcm_token')],['user_id' => $user->id]);
            }
            $user = User::findOrFail($user_id);
            $user['access_token'] = $user->createToken('mobile')->accessToken;

            $message = __('api.ok');
                return response()->json(['status' => true, 'code' => 200, 'message' => $message,'user'=>$user]);
        } else {
            $message = __('api.not_edit');
            return response()->json(['status' => false, 'code' => 200,
                'message' => $message, 'validator' => $validator ]);
        }
    }

    public function changePassword(Request $request)
    {
        $rules = [
            'old_password' => 'required|min:6',
            'password' => 'required|min:6',
            'confirm_password' => 'required|min:6|same:password',
        ];
        $validator = Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return response()->json(['status' => false, 'code' => 200,
                'message' =>implode("\n",$validator-> messages()-> all())]);
        }
        $user = auth('api')->user();

        if (!Hash::check($request->get('old_password'), $user->password)) {
            $message = __('api.wrong_old_password'); //wrong old
            return response()->json(['status' => false, 'code' => 200,'message' => $message ]);
        }

        $user->password = bcrypt($request->get('password'));

        if ($user->save()) {
            $user->refresh();
            $message = __('api.ok');
            return response()->json(['status' => true, 'code' => 200,'message' => $message ]);
        }
        $message = __('api.whoops');
        return response()->json(['status' => false, 'code' => 200,'message' => $message ]);
    }

    public function logout(Request $request)
    {
        $user_id = auth('api')->id();
        
         if ($request->has('fcm_token')) {
                 
                Token::where('fcm_token' , $request->get('fcm_token'))->delete();
            }
        if (auth('api')->user()->token()->revoke()) {
            $message = 'logged out successfully';
            return response()->json(['status' => true, 'code' => 200,
                'message' => $message ]);
        } else {
            $message = 'logged out successfully';
            return response()->json(['status' => true, 'code' => 202,
                'message' => $message ]);
        }
    }

    
    
    public function updateNotificationStatus(Request $request)
    {
        Token::updateOrCreate(['fcm_token' => $request->get('fcmToken'), 'device_type' => $request->get('device_type'),
            'lang' => app()->getLocale() ,'notification_status' => $request->get('notification_status')]);
        if(auth('api')->check()){
            $user_id = auth('api')->id();
            $user = User::query()->findOrFail($user_id);
            $user->notification_status=$request->get('notification_status');
            $user->save();

            Token::where('user_id',$user_id)->update(['notification_status' => $request->get('notification_status')]);

        }
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message]);
    }
    
 

    public function removeMyAccount(Request $request)
    {
             $user_id = auth('api')->id();
             Token::where('user_id',$user_id)->delete();
 
             $user=  User::findOrFail(auth('api')->id());
             
             $user->delete_reason ='deleted from user';
             $user->status ='not_active';
             $user->save();
             $user->delete();


        if (auth('api')->user()->token()->revoke()) {
            $message =  __('api.Account deleted successfully') ;
            
            return response()->json(['status' => true, 'code' => 200,
                'message' => $message ]);
        } else {
            $message = __('api.Account deleted successfully');
            return response()->json(['status' => true, 'code' => 202,
                'message' => $message ]);
        }
    }
    


    public function addNewAdress(Request $request){
             $validator = Validator::make($request->all(), [
                'address_name' => 'required',
                'governorate_id' => 'required',
                'area_id' => 'required',
                'block' => 'required',
                'street' => 'required',
              ]);
          
             if ($validator->fails()) {
                 return response()->json(['status' => false, 'code' => 200,
                     'message' =>implode("\n",$validator-> messages()-> all()) ]);
             }
             $address= new UserAddress();
             $address->user_id =auth('api')->id();
             $address->address_name =$request->address_name;
             $address->governorate_id =$request->governorate_id;
             $address->area_id =$request->area_id;
             $address->block =$request->block;
             $address->street =$request->street;
             $address->building_number =$request->building_number;
             $address->floor_number =$request->floor_number;
             $address->notes =$request->notes;
             $address->save();

             $address= UserAddress::with('area','governorate')->findOrFail($address->id);
             $message = __('api.ok');
             return response()->json(['status' => true, 'code' => 200,'message' => $message ,'address'=>$address]);
      
    }
    

    public function getMyAddresses(){
        $data = UserAddress::where('user_id',auth('api')->id())->orderBy('id','desc')->with('area','governorate')->paginate($this->paginateTotal)->items();
        $is_more = ($this->paginateTotal > count($data) )? false:true;
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200,'message' => $message,'items'=>$data ,'is_more'=>$is_more]);
    }


    public function updateAdress(Request $request,$id){
        $validator = Validator::make($request->all(), [
            'address_name' => 'required',
            'governorate_id' => 'required',
            'area_id' => 'required',
            'block' => 'required',
            'street' => 'required',
        ]);
     
        if ($validator->fails()) {
            return response()->json(['status' => false, 'code' => 200,
                'message' =>implode("\n",$validator-> messages()-> all()) ]);
        }
        $address= UserAddress::where('user_id',auth('api')->id())->findOrFail($id);
        $address->address_name =$request->address_name;
        $address->governorate_id =$request->governorate_id;
        $address->area_id =$request->area_id;
        $address->block =$request->block;
        $address->street =$request->street;
        $address->building_number =$request->building_number;
        $address->floor_number =$request->floor_number;
        $address->notes =$request->notes;
        $address->save();

        $address= UserAddress::with('area','governorate')->findOrFail($address->id);
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200,'message' => $message ,'address'=>$address]);
 
}


    public function deleteAddress($id){
        $data = UserAddress::where('user_id',auth('api')->id())->findOrFail($id);;
        $data->delete();
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200,'message' => $message]);
    }


    public function myNotifications(){
        $data = Notifiy::where('user_id',auth('api')->id())->orderBy('id','desc')->paginate($this->paginateTotal)->items();
        $is_more = ($this->paginateTotal > count($data) )? false:true;
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200,'message' => $message,'items'=>$data ,'is_more'=>$is_more]);
    }



    
    
   public function getMyOrders(Request $request)
    {
        $items = Order::where('payment_status',1)->where('user_id', auth('api')->id())->orderBy("id", 'desc')->withCount('products')->paginate($this->paginateTotal)->items();
        $is_more = ($this->paginateTotal > count($items))? false:true;

        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message, 'items' => $items,'is_more'=>$is_more]);
    }
    
    
   public function getOrderById(Request $request,$id)
    {
        $item = Order::where('payment_status',1)->where('user_id', auth('api')->id())->with('products.product','products.color', 'products.size','address.area')->findOrFail($id);
        $server_time=now();
        $message = __('api.ok');
        return response()->json(['status' => true, 'code' => 200, 'message' => $message, 'item' => ['item'=>$item ,'server_time'=>$server_time]]);
    }    

       
 

 

}
