<?php
namespace App\Http\Controllers\WEB\Admin;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Response;
use Image;
use App\Models\Language;
use App\Models\Setting;
use App\Models\Banner;
use App\Models\Category;
use App\Models\Product;
use App\Models\Subadmin;
use Illuminate\Support\Facades\Validator;
 use Illuminate\Support\Facades\Route;
use DataTables;
use App\Traits\ImageTrait;
class BannerController extends Controller
{
    use ImageTrait;
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->settings = Setting::query()->first();
        view()->share([
            'settings' => $this->settings,

        ]);
        
         $route=Route::currentRouteAction();
         $route_name = substr($route, strpos($route, "@") + 1);   
         $this->middleware(function ($request, $next) use($route_name){
         if(can('banners')){
            return $next($request);  
         }
          if($route_name== 'index' ){
             if(can(['banners-show' , 'banners-create' , 'banners-edit' , 'banners-delete'])){
                 return $next($request);  
             }
          }elseif($route_name== 'create' || $route_name== 'store'){
              if(can('banners-create')){
                 return $next($request);  
             } 
          }elseif($route_name== 'edit' || $route_name== 'update'){
              if(can('banners-edit')){
                 return $next($request);  
             } 
          }elseif($route_name== 'destroy' || $route_name== 'delete'){
              if(can('banners-delete')){
                 return $next($request);  
             } 
          }else{
              return $next($request);  
          }
          if($request->ajax()){
            $message = __('cp.you_dont_have_premession');
            return response()->json(['status' => false, 'code' => 503, 'message' => $message, ]);
          }else{
            return redirect()->back()->withErrors(__('cp.you_dont_have_premession'));
          }
        });
    }

    public function index(Request $request)
    {
        $items  = Banner::orderBy('id', 'desc')->get();
        return view('admin.banners.home', [
            'items'=>$items
        ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */

     public function create(Request $request)
     {
         $categories= Category::get();
         $products=   Product::get();
         return view('admin.banners.create', [
             'categories' => $categories,
             'products' => $products,
  
         ]);
     }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $roles = [
            'type' => 'required',
            'image' => 'required|mimes:jpeg,bmp,png,gif',
            'product_id' => 'required_if:type,==,1',
            'category_id' => 'required_if:type,==,2',
            'link' => 'required_if:type,==,3',
         ];
        $this->validate($request, $roles);

        $item= new Banner();
        $item->type=$request->type;
        if($request->type==1){
            $item->item_id=$request->product_id;
        }elseif($request->type==2){
            $item->item_id=$request->category_id;
        }elseif($request->type==3){
            $item->link=$request->link;
        }
       
        if ($request->hasFile('image')) {
            $item->image =  $this->storeImage($resize_image=0, $request->file('image'), 'banners');
        }
        $item->save();
        
        return redirect()->back()->with('status', __('cp.create'));
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */

   
        public function edit($id)
        {
           $item = Banner::where('id',$id)->first();
           $categories= Category::get();
           $products=   Product::get();
            return view('admin.banners.edit', [
                'item' => $item,
                'categories' => $categories,
                'products' => $products,
                
            ]);
        }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $roles = [
            'type' => 'required',
            'image' => 'mimes:jpeg,bmp,png,gif',
            'product_id' => 'required_if:type,==,1',
            'category_id' => 'required_if:type,==,2',
            'link' => 'required_if:type,==,3',
         ];
        $this->validate($request, $roles);

        $item = Banner::query()->findOrFail($id);
        $item->type=$request->type;
        if($request->type==1){
            $item->item_id=$request->product_id;
        }elseif($request->type==2){
            $item->item_id=$request->category_id;
        }elseif($request->type==3){
            $item->link=$request->link;
        }

        if ($request->hasFile('image')) {
            $item->image =  $this->storeImage($resize_image=0, $request->file('image'), 'banners');
        }

        $item->save();
        return redirect()->back()->with('status', __('cp.update'));

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
        $ad = Banner::query()->findOrFail($id);
        if ($ad) {
            Banner::query()->where('id', $id)->delete();

            return "success";
        }
        return "fail";
    }
}
