<?php
namespace App\Http\Controllers\WEB\Admin;
use Image;
use DataTables;
use App\Models\Area;
use App\Models\Setting;
use App\Models\Language;
use App\Models\Location;
use App\Models\Governorate;
 use Illuminate\Support\Facades\Route;
 use App\Traits\ImageTrait;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class LocationController extends Controller
{
    use ImageTrait;
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->settings = Setting::query()->first();
        view()->share([
            'settings' => $this->settings,
        ]);
        
         $route=Route::currentRouteAction();
         $route_name = substr($route, strpos($route, "@") + 1);   
         $this->middleware(function ($request, $next) use($route_name){
          if($route_name== 'index' ){
             if(can(['locations-show' , 'locations-create' , 'locations-edit' , 'locations-delete'])){
                 return $next($request);  
             }
          }elseif($route_name== 'create' || $route_name== 'store'){
              if(can('locations-create')){
                 return $next($request);  
             } 
          }elseif($route_name== 'edit' || $route_name== 'update'){
              if(can('locations-edit')){
                 return $next($request);  
             } 
          }elseif($route_name== 'destroy' || $route_name== 'delete'){
              if(can('locations-delete')){
                 return $next($request);  
             } 
          }else{
              return $next($request);  
          }
          if($request->ajax()){
            $message = __('cp.you_dont_have_premession');
            return response()->json(['status' => false, 'code' => 503, 'message' => $message, ]);
          }else{
            return redirect()->back()->withErrors(__('cp.you_dont_have_premession'));
          }
        });
    }

    public function index(Request $request)
    {
        $items = Location::query()->filter()->orderBy('id', 'desc')->paginate(30);
        return view('admin.locations.home', [
            'items' => $items,
        ]);

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */

      public function create(Request $request)
    {
        $governorates=Governorate::get();
        return view('admin.locations.create', [
            'governorates'=>$governorates,
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $roles = [
            'governorate_id'=>'required',
            'area_id'=>'required',
            'mobile'=>'required',
            'latitude'=>'required',
            'longitude'=>'required',
         ];
         $locales = Language::all()->pluck('lang');
         foreach ($locales as $locale) {
             $roles['name_' . $locale] = 'required';
             $roles['address_' . $locale] = 'required';
             $roles['working_hours_' . $locale] = 'required';
         }
    
        $this->validate($request, $roles);

        $item= new Location();
        foreach ($locales as $locale)
        {
            $item->translateOrNew($locale)->name = $request->get('name_' . $locale);
            $item->translateOrNew($locale)->address = $request->get('address_' . $locale);
            $item->translateOrNew($locale)->working_hours = $request->get('working_hours_' . $locale);
        }
        $item->governorate_id =$request->governorate_id;
        $item->area_id =$request->area_id;
        $item->mobile =$request->mobile;
        $item->latitude =$request->latitude;
        $item->longitude =$request->longitude;
        $item->save();
        
        return redirect()->back()->with('status', __('cp.create'));
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */

   
        public function edit($id)
        {
           $item = Location::where('id',$id)->first();
           $governorates=Governorate::get();
           $areas=Area::where('governorate_id',$item->governorate_id)->get();
            return view('admin.locations.edit', [
                'item' => $item,
                'governorates' => $governorates,
                'areas' => $areas,
            ]);
        }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $roles = [
            'governorate_id'=>'required',
            'area_id'=>'required',
            'mobile'=>'required',
            'latitude'=>'required',
            'longitude'=>'required',
         ];
         $locales = Language::all()->pluck('lang');
         foreach ($locales as $locale) {
            $roles['name_' . $locale] = 'required';
            $roles['address_' . $locale] = 'required';
            $roles['working_hours_' . $locale] = 'required';
         }

        $this->validate($request, $roles);

        $item = Location::query()->findOrFail($id);
        foreach ($locales as $locale)
        {
            $item->translateOrNew($locale)->name = $request->get('name_' . $locale);
            $item->translateOrNew($locale)->address = $request->get('address_' . $locale);
            $item->translateOrNew($locale)->working_hours = $request->get('working_hours_' . $locale);
        }

        $item->governorate_id =$request->governorate_id;
        $item->area_id =$request->area_id;
        $item->mobile =$request->mobile;
        $item->latitude =$request->latitude;
        $item->longitude =$request->longitude;

        $item->save();
        return redirect()->back()->with('status', __('cp.update'));

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
        $ad = Location::query()->findOrFail($id);
        if ($ad) {
            Location::query()->where('id', $id)->delete();

            return "success";
        }
        return "fail";
    }
}
