<?php
namespace App\Http\Controllers\WEB\Admin;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Response;
use Image;
use App\Models\Language;
use App\Models\Setting;
use App\Models\Section;
use App\Models\Category;
use App\Models\Product;
use Illuminate\Support\Facades\Validator;
 use Illuminate\Support\Facades\Route;
 use App\Traits\ImageTrait;
use DataTables;

class MainCategoryController extends Controller
{
    use ImageTrait;
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {

         $route=Route::currentRouteAction();
         $route_name = substr($route, strpos($route, "@") + 1);   
         $this->middleware(function ($request, $next) use($route_name){
          if($route_name== 'index' ){
             if(can(['categories-show' , 'categories-create' , 'categories-edit' , 'categories-delete'])){
                 return $next($request);  
             }
          }elseif($route_name== 'create' || $route_name== 'store'){
              if(can('categories-create')){
                 return $next($request);  
             } 
          }elseif($route_name== 'edit' || $route_name== 'update'){
              if(can('categories-edit')){
                 return $next($request);  
             } 
          }elseif($route_name== 'destroy' || $route_name== 'delete'){
              if(can('categories-delete')){
                 return $next($request);  
             } 
          }else{
              return $next($request);  
          }
          if($request->ajax()){
            $message = __('cp.you_dont_have_premession');
            return response()->json(['status' => false, 'code' => 503, 'message' => $message, ]);
          }else{
            return redirect()->back()->withErrors(__('cp.you_dont_have_premession'));
          }
        });
    }

    public function index(Request $request)
    {
        $items = Category::query()->filter()->where('type',1)->orderBy('id', 'desc')->withCount('products')->paginate(30);
        return view('admin.mainCategories.home', [
            'items' => $items,
        ]);

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */

      public function create(Request $request)
    {
        return view('admin.mainCategories.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $roles = [
             'image' => 'required|mimes:jpeg,bmp,png,gif,svg',
         ];
         $locales = Language::all()->pluck('lang');
         foreach ($locales as $locale) {
             $roles['name_' . $locale] = 'required';
         }
    
        $this->validate($request, $roles);

        $item= new Category();
        foreach ($locales as $locale)
        {
            $item->translateOrNew($locale)->name = $request->get('name_' . $locale);
        }
         $item->type=1;
 
        if ($request->hasFile('image')) {
            $item->image =  $this->storeImage($resize_image=0,$request->file('image'), 'categories' );;
        }
        $item->save();
        
        return redirect()->back()->with('status', __('cp.create'));
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */

   
        public function edit($id)
        {
           $item = Category::where('id',$id)->first();
            return view('admin.mainCategories.edit', [
                'item' => $item,
            ]);
        }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $roles = [
            // 'image' => 'mimes:jpeg,bmp,png,gif,svg',
         ];
         $locales = Language::all()->pluck('lang');
         foreach ($locales as $locale) {
             $roles['name_' . $locale] = 'required';
         }

        $this->validate($request, $roles);

        $item = Category::query()->findOrFail($id);
        foreach ($locales as $locale)
        {
            $item->translateOrNew($locale)->name = $request->get('name_' . $locale);
        }
  
        if ($request->hasFile('image')) {
            $item->image =  $this->storeImage($resize_image=0,$request->file('image'), 'categories' );;
        }
        $item->save();
        return redirect()->back()->with('status', __('cp.update'));

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
        $ad = Category::query()->findOrFail($id);
        if ($ad) {
            Category::query()->where('id', $id)->delete();

            return "success";
        }
        return "fail";
    }
}
