<?php

namespace App\Http\Controllers\WEB\Admin;


use App\Models\ServiceImage;
use App\Models\Category;
use App\Models\Language;
use App\Models\VehicleType;
use App\Models\Setting;
use App\Models\permissions;
use App\Models\ClientForm;
use App\Models\Cart;
use App\Models\SubCategory;
use App\Models\Size;
use App\Models\Permission;
use App\Models\PermissionOption;
use App\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Image;
use Auth;
use Illuminate\Support\Facades\Validator;
 use Illuminate\Support\Facades\Route;
use DataTables;
class PermissionController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->locales = Language::all();
        $this->settings = Setting::query()->first();
        view()->share([
            'locales' => $this->locales,
            'settings' => $this->settings,

        ]);
        
         $route=Route::currentRouteAction();
         $route_name = substr($route, strpos($route, "@") + 1);   
         $this->middleware(function ($request, $next) use($route_name){
          if($route_name== 'index' ){
             if(can(['permissions-show' , 'permissions-create' , 'permissions-edit' , 'permissions-delete'])){
                 return $next($request);  
             }
          }elseif($route_name== 'create' || $route_name== 'store'){
              if(can('permissions-create')){
                 return $next($request);  
             } 
          }elseif($route_name== 'edit' || $route_name== 'update'){
              if(can('permissions-edit')){
                 return $next($request);  
             } 
          }elseif($route_name== 'destroy' || $route_name== 'delete'){
              if(can('permissions-delete')){
                 return $next($request);  
             } 
          }else{
              return $next($request);  
          }
          if($request->ajax()){
            $message = __('cp.you_dont_have_premession');
            return response()->json(['status' => false, 'code' => 503, 'message' => $message, ]);
          }else{
            return redirect()->back()->withErrors(__('cp.you_dont_have_premession'));
          }
        });
    }
 

    public function index(Request $request)
    {
        $items = Permission::orderBy('id', 'asc')->paginate(30);
        return view('admin.permissions.home', [
            'items' => $items,
        ]);

    }

   

    public function create(Request $request)
    {
        return view('admin.permissions.create', [
        ]);
    }

    public function store(Request $request)
    {

       
            if($request->has('options') ){
                foreach ($request->options as $one){
                    $option= new Permission();
                    $option->translateOrNew('en')->name =$one['name_en'];
                    $option->translateOrNew('ar')->name = $one['name_ar'];
                    // $option->permission_id=$item->id;
                    $option->slug=$one['slug'];
                    $option->save();
                }
            }
      

  
        return redirect()->back()->with('status', __('cp.create'));
    }

 
    public function edit(Request $request, $id)
    {
        $item = Permission::where('id',$id)->with('PermissionOptions')->findOrFail($id);
        return view('admin.permissions.edit', [
            'item' => $item,
        ]);
    }

    public function update(Request $request, $id)
    {
 
        $roles = [
            'type' => 'required',
            // 'old_options' => 'required_without:options|array|required_if:input_type,==,2',
            // 'options' => 'required_without:old_options|array|required_if:input_type,==,2',
             
        ];

        $locales = Language::all()->pluck('lang');

        foreach ($locales as $locale) {
            $roles['name_' . $locale] = 'required';
        }

        $this->validate($request, $roles);

        $item = Permission::findOrFail($id);
        $item->type = $request->type;
        foreach ($locales as $locale)
        {
            $item->translateOrNew($locale)->name = $request->get('name_' . $locale);
        }
        $item->save();
         if($request->has('oldOptionsIdas')){
            PermissionOption::whereNotIn('id',$request->oldOptionsIdas)->where('Permission_id',$item->id)->delete();
         }
        
        if($request->has('old_options')){
            foreach ($request->old_options as $one){
                $option= PermissionOption::where('id',$one['id'])->first();
                if($option){
                    $option->translateOrNew('en')->name =$one['name_en'];
                    $option->translateOrNew('ar')->name = $one['name_ar'];
                    $option->Permission_id=$item->id;
                    $option->save();
                }
            }
        }
        

            if($request->has('options') ){
                foreach ($request->options as $one){
                    $option= new PermissionOption();
                    $option->translateOrNew('en')->name =$one['name_en'];
                    $option->translateOrNew('ar')->name = $one['name_ar'];
                    $option->Permission_id=$item->id;
                    $option->save();
                }
            }

   

        return redirect()->back()->with('status', __('cp.update'));
    }


    public function destroy($id)
    {
        // return $id;
        $item = Permission::query()->findOrFail($id);
        if ($item) {
            Permission::query()->where('id', $id)->delete();
            return "success";
        }
        return "fail";
    }
    
    
    
 
 
}