<?php

namespace App\Http\Controllers\WEB\Admin;

use App\Models\Age;
use App\Models\ProductAge;
use App\Models\ServiceImage;
use App\Models\Category;
use App\Models\Language;
use App\Models\Product;
use App\Models\Setting;
use App\Models\ProductImage;
use App\Models\Productoffer;
use App\Models\Color;
use App\Models\Size;
use App\Models\ProductColor;
use App\Models\ProductSize;
use App\Models\ProductCategory;
use App\Models\Country;
use App\Models\Cart;
use App\Models\Subadmin;
use App\Models\SubCategory;
use App\Models\ProductQuantity;
use App\Models\ProductGender;

use App\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Image;
use Auth;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Route;
use DataTables;
use App\Traits\ImageTrait;

class ProductController extends Controller
{
    use ImageTrait;
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->locales = Language::all();
        $this->settings = Setting::query()->first();
        view()->share([
            'locales' => $this->locales,
            'settings' => $this->settings,

        ]);

        $route=Route::currentRouteAction();
        $route_name = substr($route, strpos($route, "@") + 1);
        $this->middleware(function ($request, $next) use ($route_name) {
            if ($route_name== 'index') {
                if (can(['products-show' , 'products-create' , 'products-edit' , 'products-delete'])) {
                    return $next($request);
                }
            } elseif ($route_name== 'create' || $route_name== 'store') {
                if (can('products-create')) {
                    return $next($request);
                }
            } elseif ($route_name== 'edit' || $route_name== 'update') {
                if (can('products-edit')) {
                    return $next($request);
                }
            } elseif ($route_name== 'destroy' || $route_name== 'delete') {
                if (can('products-delete')) {
                    return $next($request);
                }
            } else {
                return $next($request);
            }
            if ($request->ajax()) {
                $message = __('cp.you_dont_have_premession');
                return response()->json(['status' => false, 'code' => 503, 'message' => $message, ]);
            } else {
                return redirect()->back()->withErrors(__('cp.you_dont_have_premession'));
            }
        });
    }

    public function index(Request $request)
    {
        $items = Product::query()->filter()->orderBy('id','desc')->paginate(30);

        $categories=Category::get();
        $ages=Age::get();
        return view('admin.products.home', [
            'items'=>$items,
            'categories'=>$categories,
            'ages'=>$ages,
        ]);
    }

    public function create(Request $request)
    {
        $categories=Category::get();
        $ages=Age::get();
        $colors=Color::get();
        $sizes=Size::get();

        return view('admin.products.create', [
            'categories' => $categories,
            'colors'=>$colors,
            'sizes'=>$sizes,
            'ages'=>$ages,
        ]);
    }

    public function store(Request $request)
    {
        
        $roles = [
            'image' => 'required|mimes:jpeg,bmp,png,gif',
            'price' => 'required|numeric',
            'quantity' => 'required_if:has_variants,==,0',
         ];

        $locales = Language::all()->pluck('lang');
        foreach ($locales as $locale) {
            $roles['name_' . $locale] = 'required';
            $roles['description_' . $locale] = 'required';
        }

        $this->validate($request, $roles);
        $product= new Product();
        if($request->has_variants == 1 && ($request->colors || $request->sizes)){
             $product->has_attributes = 1;
        }else{
             $product->has_attributes = 2;
             $product->sku = substr(str_shuffle(str_repeat("123456789", 5)), 0, 6);
        }
       
        $product->price = $request->price;
        $product->quantity = $request->quantity;
        $product->is_new_arrival = $request->is_new_arrival;
        $product->is_best_seller = $request->is_best_seller;
        $product->is_featured = $request->is_featured;
        if ($request->discount_price !='' && $request->discount_price > 0) {
            $product->discount_price = $request->discount_price;
        } else {
            $product->discount_price = 0;
        }

            
        if ($request->hasFile('image')) {
            $product->image =  $this->storeImage($resize_image=1, $request->file('image'), 'products');
        }

        foreach ($locales as $locale) {
            $product->translateOrNew($locale)->name = $request->get('name_' . $locale);
            $product->translateOrNew($locale)->description = $request->get('description_' . $locale);
        }

        $product->save();

        if($request->has('filename')  && !empty($request->filename))
        {
           foreach($request->filename as $one)
           {
               if (isset(explode('/', explode(';', explode(',', $one)[0])[0])[1])) {
                    $fileType = strtolower(explode('/', explode(';', explode(',', $one)[0])[0])[1]);
                    $name = auth()->guard('admin')->user()->id. "_" .str_random(8) . "_" .  "_" . time() . "_" . rand(1000000, 9999999);
                    $attachType = 0;
                    if (in_array($fileType, ['jpg','jpeg','png','pmb'])){
                        $newName = $name. ".jpg";
                        $attachType = 1;
                        Image::make($one)->resize(800, null, function ($constraint) {$constraint->aspectRatio();})->save("uploads/images/products/$newName");
                    }
                    $product_image=new ProductImage();
                    $product_image->product_id = $product->id;
                    $product_image->image = $newName;
                    $product_image->save();
                }
           }
        }


        if ($request->get('colors') != null && $request->has_variants == 1) {
            foreach ($request->colors as $id => $color) {
                if ($color !='') {
                    $data[] = [
                        'color_id' => $color,
                        'product_id' => $product->id,
                    ];
                }
            }
            ProductColor::insert($data);
        }
        if ($request->get('sizes') != null && $request->has_variants == 1) {
            foreach ($request->sizes as $id => $size) {
                if ($size !='') {
                    $sizes[] = [
                        'size_id' => $size,
                        'product_id' => $product->id,
                    ];
                }
            }
            ProductSize::insert($sizes);
        }
        
        if ($request->get('categories') != null) {
            foreach ($request->categories as $id => $category) {
                if ($category !='') {
                    $categories[] = [
                        'category_id' => $category,
                        'product_id' => $product->id,
                    ];
                }
            }
            ProductCategory::insert($categories);
        }
        if ($request->get('ages') != null) {
            foreach ($request->ages as $id => $age) {
                if ($age !='') {
                    $ages[] = [
                        'age_id' => $age,
                        'product_id' => $product->id,
                    ];
                }
            }
            ProductAge::insert($ages);
        }

        return redirect()->back()->with('status', __('cp.create'));
    }


    public function edit(Request $request, $id)
    {
        $item = Product::where('id', $id)->with('images')->findOrFail($id);
        $categories=Category::get();
        $ages=Age::get();
        $colors=Color::get();
        $sizes=Size::get();
        return view('admin.products.edit', [
            'item' => $item,
            'categories' => $categories,
            'colors'=>$colors,
            'sizes'=>$sizes,
            'ages'=>$ages,
        ]);
    }

    public function update(Request $request, $id)
    {
 
        $roles = [
            'image' => 'image|mimes:jpeg,jpg,png',
            'price' => 'required|numeric',
            'quantity' => 'required_if:has_variants,==,0',
         ];

        $locales = Language::all()->pluck('lang');
        foreach ($locales as $locale) {
            $roles['name_' . $locale] = 'required';
            $roles['description_' . $locale] = 'required';
        }

        $this->validate($request, $roles);

        $product = Product::with('images')->findOrFail($id);
        $product->price = $request->price;
        $product->quantity = $request->quantity;
        $product->is_new_arrival = $request->is_new_arrival;
        $product->is_best_seller = $request->is_best_seller;
        $product->is_featured = $request->is_featured;
        if ($request->discount_price !='' && $request->discount_price > 0) {
            $product->discount_price = $request->discount_price;
        } else {
            $product->discount_price = 0;
        }
        
        if($request->has_variants ==1 && ($request->colors || $request->sizes)){
             $product->has_attributes = 1;
        }else{
             $product->has_attributes = 2;
             if($product->sku==''){
                 $product->sku = substr(str_shuffle(str_repeat("123456789", 5)), 0, 6);
             }
        }
        
     

        foreach ($locales as $locale) {
            $product->translateOrNew($locale)->name = $request->get('name_' . $locale);
            $product->translateOrNew($locale)->description = $request->get('description_' . $locale);
        }
        
        if ($request->hasFile('image')) {
            $product->image =  $this->storeImage($resize_image=1, $request->file('image'), 'products');
        }
       
        $product->save();

        $imgsIds = $product->images->pluck('id')->toArray();
        $newImgsIds = ($request->has('oldImages')) ? $request->oldImages : [];
        $diff = array_diff($imgsIds, $newImgsIds);
        ProductImage::whereIn('id', $diff)->delete();

        if($request->has('filename')  && !empty($request->filename)){
            foreach($request->filename as $one)
            {
                if (isset(explode('/', explode(';', explode(',', $one)[0])[0])[1])) {
                     $fileType = strtolower(explode('/', explode(';', explode(',', $one)[0])[0])[1]);
                     $name = auth()->guard('admin')->user()->id. "_" .str_random(8) . "_" .  "_" . time() . "_" . rand(1000000, 9999999);
                     $attachType = 0;
                     if (in_array($fileType, ['jpg','jpeg','png','pmb'])){
                         $newName = $name. ".jpg";
                         $attachType = 1;
                         Image::make($one)->resize(800, null, function ($constraint) {$constraint->aspectRatio();})->save("uploads/images/products/$newName");
                     }
                     $product_image=new ProductImage();
                     $product_image->product_id = $product->id;
                     $product_image->image = $newName;
                     $product_image->save();
                 }
            }
         }

        
           if ($request->has_variants ==1 && $request->colors) {
            foreach ($request->colors as $color) {
                ProductColor:: updateOrCreate(['product_id' => $product->id, 'color_id' => $color],['color_id' => $color]);
            }
            $ProductColorArray = ProductColor::where('product_id', $id)->whereIn('color_id',$request->colors)->pluck('id')->toArray();
            ProductQuantity::where('product_id', $id)->whereNotIn('color_id',$ProductColorArray)->forceDelete();
            
            ProductColor::where('product_id', $id)->whereNotIn('color_id',$request->colors)->forceDelete();
        }else{
            ProductColor::where('product_id', $id)->forceDelete();
             ProductQuantity::where('product_id', $id)->whereNotNull('color_id')->forceDelete();
        }
        
          
        
 
        
         if ($request->has_variants ==1 && $request->sizes) {
            foreach ($request->sizes as $size) {
                ProductSize:: updateOrCreate(['product_id' => $product->id, 'size_id' => $size],['size_id' => $size]);
            }
            $ProductSizeArray = ProductSize::where('product_id', $id)->whereIn('size_id',$request->sizes)->pluck('id')->toArray();
            ProductQuantity::where('product_id', $id)->whereNotIn('size_id',$ProductSizeArray)->forceDelete();
             ProductSize::where('product_id', $id)->whereNotIn('size_id',$request->sizes)->forceDelete();
        }else{
             ProductSize::where('product_id', $id)->forceDelete();
             ProductQuantity::where('product_id', $id)->whereNotNull('size_id')->forceDelete();
        }
        
        if ($request->get('categories') != null) {
            foreach ($request->categories as $id => $category) {
                if ($category !='') {
                    $categories[] = [
                        'category_id' => $category,
                        'product_id' => $product->id,
                    ];
                }
            }
            ProductCategory::where('product_id', $product->id)->delete();
            ProductCategory::insert($categories);
        }
        if ($request->get('ages') != null) {
            foreach ($request->ages as $id => $age) {
                if ($age !='') {
                    $ages[] = [
                        'age_id' => $age,
                        'product_id' => $product->id,
                    ];
                }
            }
            ProductAge::where('product_id', $product->id)->delete();
            ProductAge::insert($ages);
        }
 

        return redirect()->back()->with('status', __('cp.update'));
    }


    public function destroy($id)
    {
        // return $id;
        $item = product::query()->findOrFail($id);
        if ($item) {
            product::query()->where('id', $id)->delete();
            Cart::where('product_id', $id)->delete();
            return "success";
        }
        return "fail";
    }
    public function attributes($id)
    {
        $array[]= null;
        $arrayValues[]= null;
        $skuValues[]= null;
        $product = Product::query()->where('id', $id)->first();
        $product_quantities = ProductQuantity::query()->where('product_id', $id)->get();
        
        //$times = count($product->colors) * count($product->sizes);
        $i=0;
        
        if(count($product->colors) > 0){
             foreach($product->colors as $one)
            {
                $j = 0;
                if(count($product->sizes) > 0){
                   foreach($product->sizes as $two)
                    {   
                        $array[$i][$j] = $one->id.'#$$#'.$one->color->name.'#$$#'.$two->id.'#$$#'.$two->size->name;
                        $j++;
                    } 
                }else{
                  $array[$i][$j] = $one->id.'#$$#'.$one->color->name.'#$$#'.''.'#$$#'.'';  
                }
    
                
                $i++;
            }
        }elseif(count($product->sizes) > 0){
               foreach($product->sizes as $one)
            {
                $j = 0;
                $array[$i][$j] = ''.'#$$#'.''.'#$$#'.$one->id.'#$$#'.$one->size->name;
    
                
                $i++;
            }
        }

        
        foreach($product_quantities as $obj)
        {
            $arrayValues[$obj->color_id][$obj->size_id] = $obj->qty;
            $skuValues[$obj->color_id][$obj->size_id] = $obj->sku;
        }
 
        
        return view('admin.products.attributes', [
            'item' => $product,
            'array' => $array,
           // 'product_quantities' => $product_quantities,
            'arrayValues' => $arrayValues,
            'skuValues' => $skuValues
        ]);
    }
    
    public function saveQuantities(Request $request, $id)
    {
 
        if(!empty($request->IDsArray))
        {
        foreach($request->IDsArray as $one)
        {
           
            if($one['sku_key']==''){
                 $sku = substr(str_shuffle(str_repeat("123456789", 5)), 0, 6);
            }else{
                 $sku = $one['sku_key'];
            }
           ProductQuantity:: updateOrCreate(['product_id' => $id, 'color_id' => $one['first_key'],
                    'size_id' => $one['second_key'],'sku'=>$sku],
                    ['qty'=> $one['qty']]);
            /*$items_arr[] = [
                    'product_id' => $id,
                    'color_id' => $one['first_key'],
                    'size_id' => $one['second_key'],
                    'qty'=> $one['qty']
                ];*/
        }
       // ProductQuantity::insert($items_arr);
        return '{"status":"success"}';
        }
        return '{"status":"fail"}';

        
    }
}
