<?php
namespace App\Http\Controllers\WEB\Admin;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Image;
use App\Models\Language;
use App\Models\Setting;
use App\Models\Size;
use Illuminate\Support\Facades\Validator;
 use Illuminate\Support\Facades\Route;
 use App\Traits\ImageTrait;
use DataTables;

class SizeController extends Controller
{
    use ImageTrait;
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->settings = Setting::query()->first();
        view()->share([
            'settings' => $this->settings,
        ]);
        
         $route=Route::currentRouteAction();
         $route_name = substr($route, strpos($route, "@") + 1);   
         $this->middleware(function ($request, $next) use($route_name){
          if($route_name== 'index' ){
             if(can(['sizes-show' , 'sizes-create' , 'sizes-edit' , 'sizes-delete'])){
                 return $next($request);  
             }
          }elseif($route_name== 'create' || $route_name== 'store'){
              if(can('sizes-create')){
                 return $next($request);  
             } 
          }elseif($route_name== 'edit' || $route_name== 'update'){
              if(can('sizes-edit')){
                 return $next($request);  
             } 
          }elseif($route_name== 'destroy' || $route_name== 'delete'){
              if(can('sizes-delete')){
                 return $next($request);  
             } 
          }else{
              return $next($request);  
          }
          if($request->ajax()){
            $message = __('cp.you_dont_have_premession');
            return response()->json(['status' => false, 'code' => 503, 'message' => $message, ]);
          }else{
            return redirect()->back()->withErrors(__('cp.you_dont_have_premession'));
          }
        });
    }

    public function index(Request $request)
    {
        $items = Size::query()->filter()->orderBy('id', 'desc')->paginate(30);
        return view('admin.sizes.home', [
            'items' => $items,
        ]);

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */

      public function create(Request $request)
    {
        return view('admin.sizes.create', [
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $roles = [
         ];
         $locales = Language::all()->pluck('lang');
         foreach ($locales as $locale) {
             $roles['name_' . $locale] = 'required';
         }
    
        $this->validate($request, $roles);

        $item= new Size();
        foreach ($locales as $locale)
        {
            $item->translateOrNew($locale)->name = $request->get('name_' . $locale);
        }

        $item->save();
        
        return redirect()->back()->with('status', __('cp.create'));
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */

   
        public function edit($id)
        {
           $item = Size::where('id',$id)->first();
            return view('admin.sizes.edit', [
                'item' => $item,
            ]);
        }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $roles = [
         ];
         $locales = Language::all()->pluck('lang');
         foreach ($locales as $locale) {
             $roles['name_' . $locale] = 'required';
         }

        $this->validate($request, $roles);

        $item = Size::query()->findOrFail($id);
        foreach ($locales as $locale)
        {
            $item->translateOrNew($locale)->name = $request->get('name_' . $locale);
        }
        $item->save();
        return redirect()->back()->with('status', __('cp.update'));

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
        $ad = Size::query()->findOrFail($id);
        if ($ad) {
            Size::query()->where('id', $id)->delete();

            return "success";
        }
        return "fail";
    }
}
