<?php

namespace App\Http\Controllers\WEB\Admin;


use App\Models\Governorate;
use App\Models\UserAddress;
use App\Models\Setting;
use App\Models\Order;
use App\Models\User;
use App\Models\OrderProduct;
use App\Models\Area;
use Illuminate\Support\Facades\Validator;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Image;
use Mockery\Exception;
use Illuminate\Support\Facades\Route;
use DataTables;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\UsersExport;
use Carbon\Carbon;

class UsersController extends Controller
{
    public function __construct()
    {
        $this->settings = Setting::query()->first();
        view()->share([
            'settings' => $this->settings,

        ]);
        
         $route=Route::currentRouteAction();
         $route_name = substr($route, strpos($route, "@") + 1);   
         $this->middleware(function ($request, $next) use($route_name){
         if(can('users')){
            return $next($request);  
         }
          if($route_name== 'index' ){
             if(can(['users-show' , 'users-create' , 'users-edit' , 'users-delete'])){
                 return $next($request);  
             }
          }elseif($route_name== 'create' || $route_name== 'store'){
              if(can('users-create')){
                 return $next($request);  
             } 
          }elseif($route_name== 'edit' || $route_name== 'update'){
              if(can('users-edit')){
                 return $next($request);  
             } 
          }elseif($route_name== 'destroy' || $route_name== 'delete'){
              if(can('users-delete')){
                 return $next($request);  
             } 
          }else{
              return $next($request);  
          }
          if($request->ajax()){
            $message = __('cp.you_dont_have_premession');
            return response()->json(['status' => false, 'code' => 503, 'message' => $message, ]);
          }else{
            return redirect()->back()->withErrors(__('cp.you_dont_have_premession'));
          }
        });
    }


    public function index(Request $request)
    {
        $items = User::query()->filter()->orderBy('id','desc')->withCount('orders')->paginate(30);
 
        return view('admin.users.home', [
            'items'=>$items ,
         ]);

    }


    public function create()
    {
        return view('admin.users.create',[
        ]);
    }


    public function store(Request $request)
    {

        $validator = Validator::make($request->all(), [
           // 'image_profile' => 'required|image|mimes:jpeg,jpg,png',
            'name' => 'required',
            'email' => 'required|email|unique:users',
            'mobile' => 'required|unique:users|digits_between:8,15',
            'password' => 'required|min:6',
            'confirm_password' => 'required|min:6|same:password',

        ]);
        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $newUser = new User();
        $newUser->email = $request->email;
        $newUser->name = $request->name;
        $newUser->password = bcrypt($request->password);
        $newUser->mobile = $request->mobile;

        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $extention = $image->getClientOriginalExtension();
            $file_name = str_random(15) . "" . rand(1000000, 9999999) . "" . time() . "_" . rand(1000000, 9999999) . "." . $extention;
            Image::make($image)->resize(800, null, function ($constraint) {
                $constraint->aspectRatio();
            })->save("uploads/images/users/$file_name");
            $newUser->image_profile = $file_name;
        }

        $newUser->save();
        return redirect()->back()->with('status', __('cp.create'));

    }



    public function edit($id)
    {
        $item = User::findOrFail($id);
        return view('admin.users.edit',[
            'item'=>$item ,
        ]);
    }

    public function update(Request $request, $id)
    {
        $user= User::findOrFail($id);
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email'=>'required|email|unique:users,email,'.$user->id,
            'mobile'=>'required|digits_between:8,15|unique:users,mobile,'.$user->id,
        ]);
        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }


        $user->name = $request->name;
        $user->mobile = $request->mobile;
        $user->email = $request->email;
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $extention = $image->getClientOriginalExtension();
            $file_name = str_random(15) . "" . rand(1000000, 9999999) . "" . time() . "_" . rand(1000000, 9999999) . "." . $extention;
            Image::make($image)->resize(800, null, function ($constraint) {
                $constraint->aspectRatio();
            })->save("uploads/images/users/$file_name");
            $user->image_profile = $file_name;
        }
        $user->save();

        return redirect()->back()->with('status', __('cp.update'));
    }



    public function edit_password(Request $request, $id)
    {
        $item = User::findOrFail($id);
        return view('admin.users.edit_password',['item'=>$item]);
    }


    public function update_password(Request $request, $id)
    {
        $users_rules=array(
            'password'=>'required|min:6',
            'confirm_password'=>'required|same:password|min:6',
        );
        $users_validation=Validator::make($request->all(), $users_rules);

        if($users_validation->fails())
        {
            return redirect()->back()->withErrors($users_validation)->withInput();
        }
        $user = User::findOrFail($id);
        $user->password = bcrypt($request->password);
        $user->save();

        $settings= Setting::query()->first();
        $subject = __('cp.Password_modified');
        $blade_data = array(
            'subject'=> $subject,
            'settings'=>$settings,
            'user'=>$user,
            'password'=>$request->password,
        );
        $email_data = array(
            'from' => env('MAIL_FROM_ADDRESS'),
            'fromName' => env('MAIL_FROM_NAME'),
            'to' => [$user->email]);
        try{
            // Mail::send('emails.passwordUpdated', $blade_data, function ($message) use ($email_data, $subject) {
            //     $message->to($email_data['to'])
            //         ->subject($subject)
            //         ->replyTo($email_data['from'], $email_data['fromName'])
            //         ->from($email_data['from'],$email_data['fromName']);

            // });
        }
        catch(Exception $e) {
            // do any thing  
        }
        
        return redirect()->back()->with('status', __('cp.update'));
    }

    public function destroy($id)
    {
        $item = User::query()->findOrFail($id);
        if ($item) {
            User::query()->where('id', $id)->delete();
            return "success";
        }
        return "fail";
    }

   
    public function addresses(Request $request , $id)
    {
        $item = User::findOrFail($id);
    
        $addresses = UserAddress::query();
          if ($request->has('area_id')) {
            if ($request->get('area_id') != null)
                $addresses->where('area_id', $request->get('area_id'));
        }
        
      
          if ($request->has('street')) {
            if ($request->get('street') != null)
                $addresses->where('street', $request->get('street'));
        }
        
 
            $addresses = $addresses->where('user_id',$id)->orderBy('id','desc')->paginate($this->settings->paginate);

        return view('admin.users.addresses.home',[
            'item'=>$item ,
            'addresses'=>$addresses ,
               
        ]);
    }
    
      public function createAddress($id)
    {
        $item = User::findOrFail($id);
        $governorates=Governorate::get();
        $areas=Area::get();
         return view('admin.users.addresses.create',[
            'item'=>$item,
            'areas'=>$areas,
            'governorates'=>$governorates,
         ]);
    }
      public function storeAddress(Request $request , $id)
    {
        $validator = Validator::make($request->all(), [
            'address_name' => 'required',
            'governorate_id' => 'required',
            'area_id' => 'required',
            'block' => 'required',
            'street' => 'required',
        ]);
        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $item=new UserAddress();
        $item->user_id=$id;
        $item->address_name =$request->address_name;
        $item->governorate_id =$request->governorate_id;
        $item->area_id =$request->area_id;
        $item->block =$request->block;
        $item->street =$request->street;
        $item->building_number =$request->building_number;
        $item->floor_number =$request->floor_number;
        $item->notes =$request->notes;
        $item->save();

         return redirect()->back()->with('status', __('cp.create'));
    }
    
         public function editAddress($id, $address)
    {
        $item = User::findOrFail($id);
        $address = UserAddress::findOrFail($address);
        $governorates=Governorate::get();
        $areas=Area::where('governorate_id',$address->governorate_id)->get();
        return view('admin.users.addresses.edit',[
            'item'=>$item,
            'address'=>$address,
            'areas'=>$areas,
            'governorates'=>$governorates,
        ]);
    }
    
         public function updateAddress(Request $request ,$id,$address)
    {
         $validator = Validator::make($request->all(), [
            'address_name' => 'required',
            'governorate_id' => 'required',
            'area_id' => 'required',
            'block' => 'required',
            'street' => 'required',
        ]);
        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        
        $item = UserAddress::findOrFail($address);
        $item->address_name =$request->address_name;
        $item->governorate_id =$request->governorate_id;
        $item->area_id =$request->area_id;
        $item->block =$request->block;
        $item->street =$request->street;
        $item->building_number =$request->building_number;
        $item->floor_number =$request->floor_number;
        $item->notes =$request->notes;
         $item->save();
            
          return redirect()->back()->with('status', __('cp.update'));
    }
    
      public function deleteAddress($id)
    {
         UserAddress::findOrFail($id)->delete();
         return 'success';
    }
 
  
    public function exportUsers(Request $request)  {
        return Excel::download(new UsersExport($request), 'users.xlsx');
    }

}
