<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Astrotomic\Translatable\Translatable;

class Category extends Model
{
    //
    public $translatedAttributes = ['name'];

    use SoftDeletes,Translatable;
    protected $table = 'categories';
    protected $fillable = ['image'];
    protected $hidden = ['updated_at', 'deleted_at','translations'];


    public function getImageAttribute($value)
    {
        return url('uploads/images/categories/'. $value);
    }
    
 
    public function products(){
        return $this->hasMany(ProductCategory::class,'category_id');
    }


    
    public function scopeFilter($query)
    {
        if (request()->has('name')) {
            if (request()->get('name') != null)
                $query->where(function ($q) {
                    $q->whereTranslationLike('name', '%' . request()->get('name') . '%');
                });
        }
        if (request()->has('id')) {
            if (request()->get('id') != null)
                $query->where('id', request()->get('id'));
        }
        if (request()->has('status')) {
            if (request()->get('status') != null)
                $query->where('status', request()->get('status'));
        }
        if (request()->has('is_featured')) {
            if (request()->get('is_featured') != null)
                $query->where('is_featured', request()->get('is_featured'));
        }

    }
}
