<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Astrotomic\Translatable\Translatable;
use \Carbon\Carbon;
class Location extends Model
{
    use SoftDeletes, Translatable;

    public $translatedAttributes = ['name','address' ,'working_hours'];
    protected $table = 'locations';
    protected $fillable = [];
    protected $hidden = ['updated_at', 'deleted_at','translations'];

 
 
    public function governorate()
    {
        return $this->belongsTo(Governorate::class, 'governorate_id');
    }

    public function area()
    {
        return $this->belongsTo(Area::class, 'area_id');
    }
 
    
    public function scopeFilter($query)
    {
        if (request()->has('name')) {
            if (request()->get('name') != null)
                $query->where(function ($q) {
                    $q->whereTranslationLike('name', '%' . request()->get('name') . '%');
                });
        }
        if (request()->has('status')) {
            if (request()->get('status') != null)
                $query->where('status', request()->get('status'));
        }
     
        if (request()->has('id')) {
            if (request()->get('id') != null)
                $query->where('id', request()->get('id'));
        }

        if (request()->get('from_date') && request()->get('to_date')) {
            $query->whereDate('created_at', '>=', Carbon::parse(request()->get('from_date')));
            $query->whereDate('created_at', '<=', Carbon::parse(request()->get('to_date')));
        }
     

    }
}
