<?php

namespace App\Models;

use App\Models\User;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Carbon\Carbon;

class Order extends Model
{
    use SoftDeletes ;
    protected $table = 'orders';
    protected $hidden = ['updated_at', 'deleted_at'];

    protected $guarded = [];
    protected $appends = ['status_name' ];

    public function user()
    {
        return $this->belongsTo(User::class,'user_id')->withTrashed();;
    }
   
    public function products()
    {
        return $this->hasMany(OrderProduct::class)->withTrashed();
    }

    public function address(){
        return $this->belongsTo(UserAddress::class,'address_id','id')->withTrashed();
    }
 

    public function getStatusNameAttribute()
    {
        $status ="";
        if($this->status == 1)
        {
            $status = __('cp.In Process');
        }
        else if($this->status == 2)
        {
            $status = __('cp.Out for Delivery');
        }
        else if($this->status == 3)
        {
            $status = __('cp.Delivered');
        }
        else if($this->status == 4)
        {
            $status = __('cp.Cancelled');
        }
        

        return $status;
    }
  
    public function scopeFilter($query)
    {
        if (request()->has('order_id')) {
            if (request()->get('order_id') != null)
                $query->where('id', request()->get('order_id') );
        }
        if (request()->has('status')) {
            if (request()->get('status') != null)
                $query->where('status', request()->get('status') );
        }
        if (request()->has('user_id')) {
            if (request()->get('user_id') != null)
                $query->where('user_id', request()->get('user_id') );
        }
        
 
        if (request()->has('area_id')) {
            if (request()->get('area_id') != null)
              $query->whereHas('address',function ($query) {$query->where('area_id', request()->get('area_id'));});
        }
    
        
        if (request()->has('refund_reference')) {
            if (request()->get('refund_reference') != null)
                $query->where('refund_reference', request()->get('refund_reference') );
        }
        if (request()->has('userName')) {
            if (request()->get('userName') != null)
                $query->where('name', request()->get('userName') );
        }
        if (request()->has('email')) {
            if (request()->get('email') != null)
                $query->where('email', request()->get('email') );
        }
        if (request()->has('mobile')) {
            if (request()->get('mobile') != null)
                $query->where('mobile', request()->get('mobile') );
        }
        if (request()->has('payment_status')) {
            if (request()->get('payment_status') != null)
                $query->where('payment_status', request()->get('payment_status') );
        }
        if (request()->has('payment_method')) {
            if (request()->get('payment_method') != null)
                $query->where('payment_method', request()->get('payment_method') );
        }
 
         if (request()->get('from_date') && request()->get('to_date')) {
            $query->whereDate('created_at', '>=', Carbon::parse(request()->get('from_date')));
            $query->whereDate('created_at', '<=', Carbon::parse(request()->get('to_date')));
        }
        
 

 
    }



}
