<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;


class OrderProduct extends Model
{
    use SoftDeletes;

    protected $table = 'order_products';
    protected $fillable = ['order_id', 'product_id', 'quantity', 'price'];
    protected $with = 'product';
 
    public function product()
    {
        return $this->belongsTo(Product::class, 'product_id', 'id')->withTrashed();
    }
 
    public function order()
    {
        return $this->belongsTo(Order::class,'order_id');
    }

    public function color()
    {
        return $this->belongsTo(Color::class,'color_id');
    }
    public function size()
    {
        return $this->belongsTo(Size::class,'size_id');
    }


    public function scopeFilter($query)
    {
        if (request()->has('title')) {
            if (request()->get('title') != null)
                $query->where(function ($q) {
                    $q->whereTranslationLike('title', '%' . request()->get('title') . '%');
                });
        }
        if (request()->has('status')) {
            if (request()->get('status') != null)
                $query->where('status', request()->get('status'));
        }
     
        if (request()->has('id')) {
            if (request()->get('id') != null)
                $query->where('id', request()->get('id'));
        }

        if (request()->get('from_date') && request()->get('to_date')) {
            $query->whereDate('created_at', '>=', Carbon::parse(request()->get('from_date')));
            $query->whereDate('created_at', '<=', Carbon::parse(request()->get('to_date')));
        }
     

    }
 
}
