<?php

namespace App\Models;

use Astrotomic\Translatable\Translatable;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Auth;
use Illuminate\Support\Str;
use Session;
class Product extends Model
{
    public $translatedAttributes = ['description', 'name'];

    use SoftDeletes, Translatable;

    protected $table = 'products';
    protected $guarded = [];
    protected $hidden = ['updated_at', 'deleted_at','translations'];
    protected $appends = ['is_cart','is_out_stock','discount_percent','is_fevorite','url_link']; //
    
  
    public function images()
    {
        return $this->hasMany(ProductImage::class);
    }
    
    
          public function getUrlLinkAttribute()
    {
          return  route('productDetails',[$this->id,Str::slug($this->name)]);
    }

    public function getImageAttribute($value)
    {
        if ($value) {
            if (filter_var($value, FILTER_VALIDATE_URL) === FALSE) {
                return url('uploads/images/products/' . $value);
            } else {
                return $value;
            }
        } else {
            return url('uploads/images/products/default.jpg');
        }
    }


    public function getDiscountPercentAttribute()
    {
        if ($this->discount_price >0 && $this->offer_end_date > now()->toDateString() ) {
            $price = $this->price;
                $discount = ($price - $this->discount_price)/$price * 100;
                
                return round($discount);
        }else{
            return 0;
        }
      
    }
    public function getIsOutStockAttribute()
    {
        if(count($this->colors) > 0 && count($this->sizes) ==0 ){
             foreach( $this->colors as $one){
                 if($one->disabled==1){
                     return 1;
                 }
                 if($one->disabled ==2){
                     return 0;
                 }
             }
        }elseif(count($this->sizes) > 0 && count($this->colors) ==0){
            foreach( $this->sizes as $one){
                 if($one->disabled==1){
                     return 1;
                 }
                 if($one->disabled ==2){
                     return 0;
                 }
             }
        }elseif(count($this->sizes) > 0 && count($this->colors) > 0){
            foreach( $this->colors as $one){
                 if($one->disabled==1){
                     return 1;
                 }
                 if($one->disabled ==2){
                     return 0;
                 }
             }
        }
        
        else{
            if($this->quantity < 1){
                return 1;
            }else{
                return 0;
            }
        }
        return 1;
    }

 


      public function carts(){
         return $this->hasMany(Cart::class,"product_id");
    }
      public function colors(){
         return $this->hasMany(ProductColor::class,"product_id");
    }
      public function sizes(){
         return $this->hasMany(ProductSize::class,"product_id");
    }
      public function ages(){
         return $this->hasMany(ProductAge::class,"product_id");
    }
      public function categories(){
         return $this->hasMany(ProductCategory::class,"product_id");
    }
      public function favorites(){
         return $this->hasMany(Favorite::class,"item_id");
    }
      public function orders(){
         return $this->hasMany(OrderProduct::class,"product_id");
    }
    
    public function getIsCartAttribute()    
    {
      return 0;
    }
    
    
    
    
       public function getIsFevoriteAttribute()  
    {
        if(auth('api')->check()){
                $fcm =$this->favorites()->where('user_id',auth('api')->id())->where('item_id',$this->id)->first();
           if($fcm){
               return "1";
           }else{
                return "0"; 
           }
        }else{
             return "0"; 
        }

         
    }

    
    public function scopeFilter($query)
    {
        if (request()->has('name')) {
            if (request()->get('name') != null)
                $query->where(function ($q) {
                    $q->whereTranslationLike('name', '%' . request()->get('name') . '%');
                });
        }
        if (request()->has('id')) {
            if (request()->get('id') != null)
                $query->where('id', request()->get('id') );
        }
        
        if (request()->has('price')) {
            if (request()->get('price') != null)
                $query->where('price', 'like', '%' . request()->get('price') . '%');
        }

        if (request()->has('status')) {
            if (request()->get('status') != null)
                $query->where('status', request()->get('status'));
        }
        if (request()->has('age_id') && request()->get('age_id') != null) {
                $query->whereHas('ages',function ($q){
                    $q->where('age_id',request()->get('age_id'));
                });     
        }
        if (request()->has('category_id') && request()->get('category_id') != null) {
                $query->whereHas('categories',function ($q){
                    $q->where('category_id',request()->get('category_id'));
                });     
        }

    }

   
}
